/*
  This file was generated automatically with ./scripts/maple2c.pl.
  Do not edit this file directly as it can be overwritten!!

  This Source Code Form is subject to the terms of the Mozilla Public
  License, v. 2.0. If a copy of the MPL was not distributed with this
  file, You can obtain one at http://mozilla.org/MPL/2.0/.

  Maple version     : Maple 2020 (X86 64 LINUX)
  Maple source      : ./maple/mgga_exc/mgga_k_gea4.mpl
  Type of functional: mgga_exc
*/

#define maple2c_order 4
#define MAPLE2C_FLAGS (XC_FLAGS_I_HAVE_EXC | XC_FLAGS_I_HAVE_VXC | XC_FLAGS_I_HAVE_FXC | XC_FLAGS_I_HAVE_KXC | XC_FLAGS_I_HAVE_LXC)


static inline void
func_unpol(const xc_func_type *p, int order, const double *rho, const double *sigma, const double *lapl, const double *tau , double *zk MGGA_OUT_PARAMS_NO_EXC(XC_COMMA double *, ))
{

#ifndef XC_DONT_COMPILE_EXC
  double t3, t4, t5, t6, t8, t9, t10, t12;
  double t13, t15, t16, t18, t19, t21, t22, t23;
  double t24, t25, t26, t27, t28, t30, t31, t32;
  double t33, t34, t36, t40, t42, t46, t48, t49;
  double t50, t51, t52, t54, t58, t59, t61, t63;
  double t66, t67, t68, t70, t74, t78;

#ifndef XC_DONT_COMPILE_VXC
  double t80, t85, t96, t99, t101, t105, t110, t114;
  double t116, t118, t120, t122, t126, t138, t142;

#ifndef XC_DONT_COMPILE_FXC
  double t147, t155, t166, t171, t175, t180, t187, t189;
  double t192, t194, t199, t208, t213, t216, t218, t220;
  double t222, t226, t228, t234;

#ifndef XC_DONT_COMPILE_KXC
  double t239, t250, t261, t264, t266, t270, t275, t286;
  double t288, t291, t293, t298, t311, t316, t321, t323;
  double t327, t331;

#ifndef XC_DONT_COMPILE_LXC
  double t349, t374, t400, t421, t429, t434, t439;
#endif

#endif

#endif

#endif

#endif



  t3 = rho[0] / 0.2e1 <= p->dens_threshold;
  t4 = M_CBRT3;
  t5 = t4 * t4;
  t6 = M_CBRTPI;
  t8 = t5 * t6 * M_PI;
  t9 = 0.1e1 <= p->zeta_threshold;
  t10 = p->zeta_threshold - 0.1e1;
  t12 = my_piecewise5(t9, t10, t9, -t10, 0);
  t13 = 0.1e1 + t12;
  t15 = POW_1_3(p->zeta_threshold);
  t16 = t15 * t15;
  t18 = POW_1_3(t13);
  t19 = t18 * t18;
  t21 = my_piecewise3(t13 <= p->zeta_threshold, t16 * p->zeta_threshold, t19 * t13);
  t22 = POW_1_3(rho[0]);
  t23 = t22 * t22;
  t24 = t21 * t23;
  t25 = M_CBRT6;
  t26 = M_PI * M_PI;
  t27 = POW_1_3(t26);
  t28 = t27 * t27;
  t30 = t25 / t28;
  t31 = M_CBRT2;
  t32 = t31 * t31;
  t33 = sigma[0] * t32;
  t34 = rho[0] * rho[0];
  t36 = 0.1e1 / t23 / t34;
  t40 = lapl[0] * t32;
  t42 = 0.1e1 / t23 / rho[0];
  t46 = t25 * t25;
  t48 = 0.1e1 / t27 / t26;
  t49 = t46 * t48;
  t50 = lapl[0] * lapl[0];
  t51 = t50 * t31;
  t52 = t34 * rho[0];
  t54 = 0.1e1 / t22 / t52;
  t58 = t49 * sigma[0];
  t59 = t34 * t34;
  t61 = 0.1e1 / t22 / t59;
  t63 = t31 * t61 * lapl[0];
  t66 = sigma[0] * sigma[0];
  t67 = t66 * t31;
  t68 = t59 * rho[0];
  t70 = 0.1e1 / t22 / t68;
  t74 = 0.1e1 + 0.5e1 / 0.648e3 * t30 * t33 * t36 + 0.5e1 / 0.54e2 * t30 * t40 * t42 + t49 * t51 * t54 / 0.2916e4 - t58 * t63 / 0.2592e4 + t49 * t67 * t70 / 0.8748e4;
  t78 = my_piecewise3(t3, 0, 0.3e1 / 0.20e2 * t8 * t24 * t74);
  if(zk != NULL && (p->info->flags & XC_FLAGS_HAVE_EXC))
    zk[0] = 0.2e1 * t78;

#ifndef XC_DONT_COMPILE_VXC

  if(order < 1) return;


  t80 = t21 / t22;
  t85 = 0.1e1 / t23 / t52;
  t96 = t31 * t70 * lapl[0];
  t99 = t59 * t34;
  t101 = 0.1e1 / t22 / t99;
  t105 = -0.5e1 / 0.243e3 * t30 * t33 * t85 - 0.25e2 / 0.162e3 * t30 * t40 * t36 - 0.5e1 / 0.4374e4 * t49 * t51 * t61 + 0.13e2 / 0.7776e4 * t58 * t96 - 0.4e1 / 0.6561e4 * t49 * t67 * t101;
  t110 = my_piecewise3(t3, 0, t8 * t80 * t74 / 0.10e2 + 0.3e1 / 0.20e2 * t8 * t24 * t105);
  if(vrho != NULL && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vrho[0] = 0.2e1 * rho[0] * t110 + 0.2e1 * t78;

  t114 = t30 * t32 * t36;
  t116 = t49 * t63;
  t118 = sigma[0] * t31;
  t120 = t49 * t118 * t70;
  t122 = 0.5e1 / 0.648e3 * t114 - t116 / 0.2592e4 + t120 / 0.4374e4;
  t126 = my_piecewise3(t3, 0, 0.3e1 / 0.20e2 * t8 * t24 * t122);
  if(vrho != NULL && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vsigma[0] = 0.2e1 * rho[0] * t126;

  t138 = 0.5e1 / 0.54e2 * t30 * t32 * t42 + t49 * lapl[0] * t31 * t54 / 0.1458e4 - t49 * t118 * t61 / 0.2592e4;
  t142 = my_piecewise3(t3, 0, 0.3e1 / 0.20e2 * t8 * t24 * t138);
  if(vrho != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vlapl[0] = 0.2e1 * rho[0] * t142;

  if(vrho != NULL && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vtau[0] = 0.0e0;

#ifndef XC_DONT_COMPILE_FXC

  if(order < 2) return;


  t147 = t21 / t22 / rho[0];
  t155 = 0.1e1 / t23 / t59;
  t166 = t31 * t101 * lapl[0];
  t171 = 0.1e1 / t22 / t59 / t52;
  t175 = 0.55e2 / 0.729e3 * t30 * t33 * t155 + 0.100e3 / 0.243e3 * t30 * t40 * t85 + 0.65e2 / 0.13122e5 * t49 * t51 * t70 - 0.13e2 / 0.1458e4 * t58 * t166 + 0.76e2 / 0.19683e5 * t49 * t67 * t171;
  t180 = my_piecewise3(t3, 0, -t8 * t147 * t74 / 0.30e2 + t8 * t80 * t105 / 0.5e1 + 0.3e1 / 0.20e2 * t8 * t24 * t175);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rho2[0] = 0.2e1 * rho[0] * t180 + 0.4e1 * t110;

  t187 = t30 * t32 * t85;
  t189 = t49 * t96;
  t192 = t49 * t118 * t101;
  t194 = -0.5e1 / 0.243e3 * t187 + 0.13e2 / 0.7776e4 * t189 - 0.8e1 / 0.6561e4 * t192;
  t199 = my_piecewise3(t3, 0, t8 * t80 * t122 / 0.10e2 + 0.3e1 / 0.20e2 * t8 * t24 * t194);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rhosigma[0] = 0.2e1 * rho[0] * t199 + 0.2e1 * t126;

  t208 = -0.25e2 / 0.162e3 * t114 - 0.5e1 / 0.2187e4 * t116 + 0.13e2 / 0.7776e4 * t120;
  t213 = my_piecewise3(t3, 0, t8 * t80 * t138 / 0.10e2 + 0.3e1 / 0.20e2 * t8 * t24 * t208);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rholapl[0] = 0.2e1 * rho[0] * t213 + 0.2e1 * t142;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rhotau[0] = 0.0e0;

  t216 = t8 * t21;
  t218 = t48 * t31;
  t220 = t216 * t155 * t46 * t218;
  t222 = my_piecewise3(t3, 0, t220 / 0.29160e5);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigma2[0] = 0.2e1 * rho[0] * t222;

  t226 = t216 * t85 * t46 * t218;
  t228 = my_piecewise3(t3, 0, -t226 / 0.17280e5);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmalapl[0] = 0.2e1 * rho[0] * t228;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmatau[0] = 0.0e0;

  t234 = my_piecewise3(t3, 0, t216 * t36 * t46 * t218 / 0.9720e4);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2lapl2[0] = 0.2e1 * rho[0] * t234;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2lapltau[0] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2tau2[0] = 0.0e0;

#ifndef XC_DONT_COMPILE_KXC

  if(order < 3) return;


  t239 = t21 / t22 / t34;
  t250 = 0.1e1 / t23 / t68;
  t261 = t31 * t171 * lapl[0];
  t264 = t59 * t59;
  t266 = 0.1e1 / t22 / t264;
  t270 = -0.770e3 / 0.2187e4 * t30 * t33 * t250 - 0.1100e4 / 0.729e3 * t30 * t40 * t155 - 0.520e3 / 0.19683e5 * t49 * t51 * t101 + 0.247e3 / 0.4374e4 * t58 * t261 - 0.1672e4 / 0.59049e5 * t49 * t67 * t266;
  t275 = my_piecewise3(t3, 0, 0.2e1 / 0.45e2 * t8 * t239 * t74 - t8 * t147 * t105 / 0.10e2 + 0.3e1 / 0.10e2 * t8 * t80 * t175 + 0.3e1 / 0.20e2 * t8 * t24 * t270);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho3[0] = 0.2e1 * rho[0] * t275 + 0.6e1 * t180;

  t286 = t30 * t32 * t155;
  t288 = t49 * t166;
  t291 = t49 * t118 * t171;
  t293 = 0.55e2 / 0.729e3 * t286 - 0.13e2 / 0.1458e4 * t288 + 0.152e3 / 0.19683e5 * t291;
  t298 = my_piecewise3(t3, 0, -t8 * t147 * t122 / 0.30e2 + t8 * t80 * t194 / 0.5e1 + 0.3e1 / 0.20e2 * t8 * t24 * t293);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2sigma[0] = 0.2e1 * rho[0] * t298 + 0.4e1 * t199;

  t311 = 0.100e3 / 0.243e3 * t187 + 0.65e2 / 0.6561e4 * t189 - 0.13e2 / 0.1458e4 * t192;
  t316 = my_piecewise3(t3, 0, -t8 * t147 * t138 / 0.30e2 + t8 * t80 * t208 / 0.5e1 + 0.3e1 / 0.20e2 * t8 * t24 * t311);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2lapl[0] = 0.2e1 * rho[0] * t316 + 0.4e1 * t213;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2tau[0] = 0.0e0;

  t321 = t216 * t250 * t46 * t218;
  t323 = my_piecewise3(t3, 0, -0.7e1 / 0.43740e5 * t321);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[0] = 0.2e1 * rho[0] * t323 + 0.2e1 * t222;

  t327 = my_piecewise3(t3, 0, 0.11e2 / 0.51840e5 * t220);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[0] = 0.2e1 * rho[0] * t327 + 0.2e1 * t228;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[0] = 0.0e0;

  t331 = my_piecewise3(t3, 0, -t226 / 0.3645e4);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapl2[0] = 0.2e1 * rho[0] * t331 + 0.2e1 * t234;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapltau[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhotau2[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma3[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapl2[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmatau2[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapl3[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapl2tau[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapltau2[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3tau3[0] = 0.0e0;

#ifndef XC_DONT_COMPILE_LXC

  if(order < 4) return;


  t349 = 0.1e1 / t23 / t99;
  t374 = my_piecewise3(t3, 0, -0.14e2 / 0.135e3 * t8 * t21 * t54 * t74 + 0.8e1 / 0.45e2 * t8 * t239 * t105 - t8 * t147 * t175 / 0.5e1 + 0.2e1 / 0.5e1 * t8 * t80 * t270 + 0.3e1 / 0.20e2 * t8 * t24 * (0.13090e5 / 0.6561e4 * t30 * t33 * t349 + 0.15400e5 / 0.2187e4 * t30 * t40 * t250 + 0.9880e4 / 0.59049e5 * t49 * t51 * t171 - 0.2717e4 / 0.6561e4 * t58 * t31 * t266 * lapl[0] + 0.41800e5 / 0.177147e6 * t49 * t67 / t22 / t264 / rho[0]));
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho4[0] = 0.2e1 * rho[0] * t374 + 0.8e1 * t275;

  t400 = my_piecewise3(t3, 0, 0.2e1 / 0.45e2 * t8 * t239 * t122 - t8 * t147 * t194 / 0.10e2 + 0.3e1 / 0.10e2 * t8 * t80 * t293 + 0.3e1 / 0.20e2 * t8 * t24 * (-0.770e3 / 0.2187e4 * t30 * t32 * t250 + 0.247e3 / 0.4374e4 * t49 * t261 - 0.3344e4 / 0.59049e5 * t49 * t118 * t266));
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[0] = 0.2e1 * rho[0] * t400 + 0.6e1 * t298;

  t421 = my_piecewise3(t3, 0, 0.2e1 / 0.45e2 * t8 * t239 * t138 - t8 * t147 * t208 / 0.10e2 + 0.3e1 / 0.10e2 * t8 * t80 * t311 + 0.3e1 / 0.20e2 * t8 * t24 * (-0.1100e4 / 0.729e3 * t286 - 0.1040e4 / 0.19683e5 * t288 + 0.247e3 / 0.4374e4 * t291));
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3lapl[0] = 0.2e1 * rho[0] * t421 + 0.6e1 * t316;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3tau[0] = 0.0e0;

  t429 = my_piecewise3(t3, 0, 0.119e3 / 0.131220e6 * t216 * t349 * t46 * t218);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[0] = 0.2e1 * rho[0] * t429 + 0.4e1 * t323;

  t434 = my_piecewise3(t3, 0, -0.77e2 / 0.77760e5 * t321);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[0] = 0.2e1 * rho[0] * t434 + 0.4e1 * t327;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[0] = 0.0e0;

  t439 = my_piecewise3(t3, 0, 0.11e2 / 0.10935e5 * t220);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapl2[0] = 0.2e1 * rho[0] * t439 + 0.4e1 * t331;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2tau2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl3[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhotau3[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl4[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl3tau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl2tau2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapltau3[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4tau4[0] = 0.0e0;

#ifndef XC_DONT_COMPILE_MXC

  if(order < 5) return;


#endif

#endif

#endif

#endif

#endif


}


static inline void
func_pol(const xc_func_type *p, int order, const double *rho, const double *sigma, const double *lapl, const double *tau , double *zk MGGA_OUT_PARAMS_NO_EXC(XC_COMMA double *, ))
{

#ifndef XC_DONT_COMPILE_EXC
  double t2, t3, t4, t5, t7, t8, t9, t12;
  double t13, t16, t17, t18, t20, t21, t22, t23;
  double t24, t25, t26, t27, t29, t30, t31, t32;
  double t33, t34, t35, t36, t38, t39, t40, t41;
  double t43, t48, t52, t54, t55, t56, t57, t59;
  double t63, t65, t66, t70, t71, t73, t77, t81;
  double t82, t83, t85, t86, t87, t88, t89, t91;
  double t92, t93, t94, t95, t97, t102, t106, t107;
  double t109, t113, t115, t116, t120, t121, t123, t127;
  double t131;

#ifndef XC_DONT_COMPILE_VXC
  double t132, t133, t134, t136, t139, t140, t144, t145;
  double t148, t150, t160, t164, t166, t170, t175, t176;
  double t178, t181, t182, t186, t189, t191, t195, t198;
  double t199, t204, t206, t209, t210, t215, t225, t229;
  double t231, t235, t240, t243, t246, t248, t250, t254;
  double t255, t258, t260, t262, t266, t274, t278, t286;
  double t290;

#ifndef XC_DONT_COMPILE_FXC
  double t293, t294, t297, t298, t299, t302, t306, t307;
  double t311, t313, t319, t320, t323, t325, t328, t338;
  double t344, t348, t353, t354, t355, t358, t361, t365;
  double t366, t370, t372, t374, t377, t379, t382, t386;
  double t390, t391, t395, t397, t405, t406, t410, t414;
  double t415, t419, t421, t428, t431, t436, t441, t445;
  double t446, t452, t453, t458, t462, t463, t473, t483;
  double t489, t493, t498, t506, t507, t510, t512, t514;
  double t519, t526, t528, t534, t539, t542, t544, t546;
  double t551, t558, t562, t567, t574, t576, t582, t590;
  double t595, t597, t598, t599, t600, t601, t603, t604;
  double t605, t606, t607, t609, t610, t611, t612, t614;
  double t615, t616, t617, t619, t620, t621, t624, t625;
  double t626, t629;

#ifndef XC_DONT_COMPILE_KXC
  double t633, t634, t637, t640, t641, t642, t645, t649;
  double t650, t654, t656, t661, t663, t666, t672, t673;
  double t676, t678, t681, t684, t694, t698, t700, t704;
  double t709, t711, t712, t715, t718, t721, t725, t726;
  double t730, t732, t734, t736, t738, t741, t743, t746;
  double t747, t748, t751, t756, t757, t759, t763, t764;
  double t768, t771, t775, t777, t781, t790, t791, t792;
  double t795, t800, t802, t806, t807, t811, t814, t815;
  double t817, t826, t828, t831, t834, t839, t843, t847;
  double t848, t852, t854, t863, t864, t869, t873, t877;
  double t878, t882, t884, t891, t899, t901, t902, t907;
  double t914, t918, t919, t926, t927, t934, t938, t939;
  double t955, t965, t969, t971, t975, t980, t988, t995;
  double t997, t999, t1002, t1004, t1006, t1011, t1018, t1022;
  double t1024, t1030, t1038, t1044, t1051, t1054, t1062, t1073;
  double t1076, t1078, t1080, t1085, t1092, t1099, t1101, t1106;
  double t1111, t1118, t1122, t1124, t1130, t1138, t1144, t1151;
  double t1154, t1162, t1176, t1181, t1183, t1184, t1186, t1187;
  double t1188, t1189, t1190, t1191, t1192, t1195, t1197, t1198;
  double t1200, t1201, t1202, t1204, t1206, t1207, t1210, t1212;
  double t1213, t1215, t1216, t1217, t1220, t1222, t1224, t1225;
  double t1226, t1229, t1231, t1233, t1234, t1235, t1237, t1239;
  double t1242, t1244, t1248, t1252, t1254, t1257, t1261, t1263;
  double t1265, t1270, t1276;

#ifndef XC_DONT_COMPILE_LXC
  double t1282, t1286, t1290, t1293, t1297, t1298, t1300, t1301;
  double t1307, t1313, t1314, t1317, t1321, t1330, t1336, t1339;
  double t1345, t1348, t1351, t1364, t1378, t1379, t1380, t1382;
  double t1383, t1389, t1394, t1397, t1401, t1408, t1412, t1416;
  double t1421, t1423, t1429, t1430, t1432, t1453, t1454, t1456;
  double t1460, t1469, t1476, t1480, t1481, t1484, t1495, t1496;
  double t1513, t1515, t1519, t1526, t1530, t1531, t1534, t1543;
  double t1546, t1547, t1549, t1551, t1552, t1567, t1580, t1584;
  double t1593, t1603, t1607, t1617, t1618, t1627, t1640, t1644;
  double t1651, t1655, t1664, t1667, t1678, t1681, t1683, t1684;
  double t1705, t1709, t1716, t1727, t1728, t1745, t1749, t1756;
  double t1764, t1773, t1783, t1785, t1786, t1791, t1796, t1803;
  double t1807, t1816, t1817, t1822, t1829, t1833, t1858, t1881;
  double t1882, t1890, t1896, t1899, t1906, t1908, t1911, t1925;
  double t1932, t1935, t1939, t1941, t1943, t1949, t1954, t1958;
  double t1967, t1968, t1970, t1976, t1978, t1987, t1989, t1992;
  double t1998, t2007, t2013, t2020, t2028, t2030, t2031, t2040;
  double t2069, t2076, t2082, t2085, t2092, t2094, t2097, t2107;
  double t2114, t2117, t2121, t2123, t2125, t2131, t2136, t2140;
  double t2149, t2150, t2152, t2158, t2160, t2169, t2171, t2174;
  double t2180, t2189, t2195, t2202, t2210, t2212, t2213, t2222;
  double t2247, t2250, t2253, t2257, t2260, t2262, t2269, t2272;
  double t2275, t2279, t2281, t2283, t2286, t2293, t2295, t2298;
  double t2304, t2307, t2310, t2315, t2318, t2330, t2335, t2340;
  double t2344, t2349, t2353, t2355, t2359, t2365, t2369, t2375;
  double t2382, t2392, t2397, t2402, t2406, t2411, t2415, t2417;
  double t2421, t2427, t2431, t2437, t2444, t2454;
#endif

#endif

#endif

#endif

#endif



  t2 = rho[0] <= p->dens_threshold;
  t3 = M_CBRT3;
  t4 = t3 * t3;
  t5 = M_CBRTPI;
  t7 = t4 * t5 * M_PI;
  t8 = rho[0] + rho[1];
  t9 = 0.1e1 / t8;
  t12 = 0.2e1 * rho[0] * t9 <= p->zeta_threshold;
  t13 = p->zeta_threshold - 0.1e1;
  t16 = 0.2e1 * rho[1] * t9 <= p->zeta_threshold;
  t17 = -t13;
  t18 = rho[0] - rho[1];
  t20 = my_piecewise5(t12, t13, t16, t17, t18 * t9);
  t21 = 0.1e1 + t20;
  t22 = t21 <= p->zeta_threshold;
  t23 = POW_1_3(p->zeta_threshold);
  t24 = t23 * t23;
  t25 = t24 * p->zeta_threshold;
  t26 = POW_1_3(t21);
  t27 = t26 * t26;
  t29 = my_piecewise3(t22, t25, t27 * t21);
  t30 = POW_1_3(t8);
  t31 = t30 * t30;
  t32 = t29 * t31;
  t33 = M_CBRT6;
  t34 = M_PI * M_PI;
  t35 = POW_1_3(t34);
  t36 = t35 * t35;
  t38 = t33 / t36;
  t39 = rho[0] * rho[0];
  t40 = POW_1_3(rho[0]);
  t41 = t40 * t40;
  t43 = 0.1e1 / t41 / t39;
  t48 = 0.1e1 / t41 / rho[0];
  t52 = t33 * t33;
  t54 = 0.1e1 / t35 / t34;
  t55 = t52 * t54;
  t56 = lapl[0] * lapl[0];
  t57 = t39 * rho[0];
  t59 = 0.1e1 / t40 / t57;
  t63 = t39 * t39;
  t65 = 0.1e1 / t40 / t63;
  t66 = sigma[0] * t65;
  t70 = sigma[0] * sigma[0];
  t71 = t63 * rho[0];
  t73 = 0.1e1 / t40 / t71;
  t77 = 0.1e1 + 0.5e1 / 0.648e3 * t38 * sigma[0] * t43 + 0.5e1 / 0.54e2 * t38 * lapl[0] * t48 + t55 * t56 * t59 / 0.5832e4 - t55 * t66 * lapl[0] / 0.5184e4 + t55 * t70 * t73 / 0.17496e5;
  t81 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t32 * t77);
  t82 = rho[1] <= p->dens_threshold;
  t83 = -t18;
  t85 = my_piecewise5(t16, t13, t12, t17, t83 * t9);
  t86 = 0.1e1 + t85;
  t87 = t86 <= p->zeta_threshold;
  t88 = POW_1_3(t86);
  t89 = t88 * t88;
  t91 = my_piecewise3(t87, t25, t89 * t86);
  t92 = t91 * t31;
  t93 = rho[1] * rho[1];
  t94 = POW_1_3(rho[1]);
  t95 = t94 * t94;
  t97 = 0.1e1 / t95 / t93;
  t102 = 0.1e1 / t95 / rho[1];
  t106 = lapl[1] * lapl[1];
  t107 = t93 * rho[1];
  t109 = 0.1e1 / t94 / t107;
  t113 = t93 * t93;
  t115 = 0.1e1 / t94 / t113;
  t116 = sigma[2] * t115;
  t120 = sigma[2] * sigma[2];
  t121 = t113 * rho[1];
  t123 = 0.1e1 / t94 / t121;
  t127 = 0.1e1 + 0.5e1 / 0.648e3 * t38 * sigma[2] * t97 + 0.5e1 / 0.54e2 * t38 * lapl[1] * t102 + t55 * t106 * t109 / 0.5832e4 - t55 * t116 * lapl[1] / 0.5184e4 + t55 * t120 * t123 / 0.17496e5;
  t131 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t92 * t127);
  if(zk != NULL && (p->info->flags & XC_FLAGS_HAVE_EXC))
    zk[0] = t81 + t131;

#ifndef XC_DONT_COMPILE_VXC

  if(order < 1) return;


  t132 = t8 * t8;
  t133 = 0.1e1 / t132;
  t134 = t18 * t133;
  t136 = my_piecewise5(t12, 0, t16, 0, t9 - t134);
  t139 = my_piecewise3(t22, 0, 0.5e1 / 0.3e1 * t27 * t136);
  t140 = t139 * t31;
  t144 = 0.1e1 / t30;
  t145 = t29 * t144;
  t148 = t7 * t145 * t77 / 0.10e2;
  t150 = 0.1e1 / t41 / t57;
  t160 = sigma[0] * t73;
  t164 = t63 * t39;
  t166 = 0.1e1 / t40 / t164;
  t170 = -0.5e1 / 0.243e3 * t38 * sigma[0] * t150 - 0.25e2 / 0.162e3 * t38 * lapl[0] * t43 - 0.5e1 / 0.8748e4 * t55 * t56 * t65 + 0.13e2 / 0.15552e5 * t55 * t160 * lapl[0] - 0.2e1 / 0.6561e4 * t55 * t70 * t166;
  t175 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t140 * t77 + t148 + 0.3e1 / 0.20e2 * t7 * t32 * t170);
  t176 = t83 * t133;
  t178 = my_piecewise5(t16, 0, t12, 0, -t9 - t176);
  t181 = my_piecewise3(t87, 0, 0.5e1 / 0.3e1 * t89 * t178);
  t182 = t181 * t31;
  t186 = t91 * t144;
  t189 = t7 * t186 * t127 / 0.10e2;
  t191 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t182 * t127 + t189);
  if(vrho != NULL && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vrho[0] = t81 + t131 + t8 * (t175 + t191);

  t195 = my_piecewise5(t12, 0, t16, 0, -t9 - t134);
  t198 = my_piecewise3(t22, 0, 0.5e1 / 0.3e1 * t27 * t195);
  t199 = t198 * t31;
  t204 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t199 * t77 + t148);
  t206 = my_piecewise5(t16, 0, t12, 0, t9 - t176);
  t209 = my_piecewise3(t87, 0, 0.5e1 / 0.3e1 * t89 * t206);
  t210 = t209 * t31;
  t215 = 0.1e1 / t95 / t107;
  t225 = sigma[2] * t123;
  t229 = t113 * t93;
  t231 = 0.1e1 / t94 / t229;
  t235 = -0.5e1 / 0.243e3 * t38 * sigma[2] * t215 - 0.25e2 / 0.162e3 * t38 * lapl[1] * t97 - 0.5e1 / 0.8748e4 * t55 * t106 * t115 + 0.13e2 / 0.15552e5 * t55 * t225 * lapl[1] - 0.2e1 / 0.6561e4 * t55 * t120 * t231;
  t240 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t210 * t127 + t189 + 0.3e1 / 0.20e2 * t7 * t92 * t235);
  if(vrho != NULL && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vrho[1] = t81 + t131 + t8 * (t204 + t240);

  t243 = t38 * t43;
  t246 = t55 * t65 * lapl[0];
  t248 = t55 * t160;
  t250 = 0.5e1 / 0.648e3 * t243 - t246 / 0.5184e4 + t248 / 0.8748e4;
  t254 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t32 * t250);
  if(vrho != NULL && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vsigma[0] = t8 * t254;

  if(vrho != NULL && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vsigma[1] = 0.0e0;

  t255 = t38 * t97;
  t258 = t55 * t115 * lapl[1];
  t260 = t55 * t225;
  t262 = 0.5e1 / 0.648e3 * t255 - t258 / 0.5184e4 + t260 / 0.8748e4;
  t266 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t92 * t262);
  if(vrho != NULL && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vsigma[2] = t8 * t266;

  t274 = 0.5e1 / 0.54e2 * t38 * t48 + t55 * lapl[0] * t59 / 0.2916e4 - t55 * t66 / 0.5184e4;
  t278 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t32 * t274);
  if(vrho != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vlapl[0] = t8 * t278;

  t286 = 0.5e1 / 0.54e2 * t38 * t102 + t55 * lapl[1] * t109 / 0.2916e4 - t55 * t116 / 0.5184e4;
  t290 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t92 * t286);
  if(vrho != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vlapl[1] = t8 * t290;

  if(vrho != NULL && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vtau[0] = 0.0e0;

  if(vrho != NULL && (p->info->flags & XC_FLAGS_HAVE_VXC))
    vtau[1] = 0.0e0;

#ifndef XC_DONT_COMPILE_FXC

  if(order < 2) return;


  t293 = 0.1e1 / t26;
  t294 = t136 * t136;
  t297 = t132 * t8;
  t298 = 0.1e1 / t297;
  t299 = t18 * t298;
  t302 = my_piecewise5(t12, 0, t16, 0, -0.2e1 * t133 + 0.2e1 * t299);
  t306 = my_piecewise3(t22, 0, 0.10e2 / 0.9e1 * t293 * t294 + 0.5e1 / 0.3e1 * t27 * t302);
  t307 = t306 * t31;
  t311 = t139 * t144;
  t313 = t7 * t311 * t77;
  t319 = 0.1e1 / t30 / t8;
  t320 = t29 * t319;
  t323 = t7 * t320 * t77 / 0.30e2;
  t325 = t7 * t145 * t170;
  t328 = 0.1e1 / t41 / t63;
  t338 = sigma[0] * t166;
  t344 = 0.1e1 / t40 / t63 / t57;
  t348 = 0.55e2 / 0.729e3 * t38 * sigma[0] * t328 + 0.100e3 / 0.243e3 * t38 * lapl[0] * t150 + 0.65e2 / 0.26244e5 * t55 * t56 * t73 - 0.13e2 / 0.2916e4 * t55 * t338 * lapl[0] + 0.38e2 / 0.19683e5 * t55 * t70 * t344;
  t353 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t307 * t77 + t313 / 0.5e1 + 0.3e1 / 0.10e2 * t7 * t140 * t170 - t323 + t325 / 0.5e1 + 0.3e1 / 0.20e2 * t7 * t32 * t348);
  t354 = 0.1e1 / t88;
  t355 = t178 * t178;
  t358 = t83 * t298;
  t361 = my_piecewise5(t16, 0, t12, 0, 0.2e1 * t133 + 0.2e1 * t358);
  t365 = my_piecewise3(t87, 0, 0.10e2 / 0.9e1 * t354 * t355 + 0.5e1 / 0.3e1 * t89 * t361);
  t366 = t365 * t31;
  t370 = t181 * t144;
  t372 = t7 * t370 * t127;
  t374 = t91 * t319;
  t377 = t7 * t374 * t127 / 0.30e2;
  t379 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t366 * t127 + t372 / 0.5e1 - t377);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rho2[0] = 0.2e1 * t175 + 0.2e1 * t191 + t8 * (t353 + t379);

  t382 = t293 * t195;
  t386 = my_piecewise5(t12, 0, t16, 0, 0.2e1 * t299);
  t390 = my_piecewise3(t22, 0, 0.10e2 / 0.9e1 * t382 * t136 + 0.5e1 / 0.3e1 * t27 * t386);
  t391 = t390 * t31;
  t395 = t198 * t144;
  t397 = t7 * t395 * t77;
  t405 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t391 * t77 + t397 / 0.10e2 + 0.3e1 / 0.20e2 * t7 * t199 * t170 + t313 / 0.10e2 - t323 + t325 / 0.10e2);
  t406 = t354 * t206;
  t410 = my_piecewise5(t16, 0, t12, 0, 0.2e1 * t358);
  t414 = my_piecewise3(t87, 0, 0.10e2 / 0.9e1 * t406 * t178 + 0.5e1 / 0.3e1 * t89 * t410);
  t415 = t414 * t31;
  t419 = t209 * t144;
  t421 = t7 * t419 * t127;
  t428 = t7 * t186 * t235;
  t431 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t415 * t127 + t421 / 0.10e2 + t372 / 0.10e2 - t377 + 0.3e1 / 0.20e2 * t7 * t182 * t235 + t428 / 0.10e2);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rho2[1] = t175 + t191 + t204 + t240 + t8 * (t405 + t431);

  t436 = t195 * t195;
  t441 = my_piecewise5(t12, 0, t16, 0, 0.2e1 * t133 + 0.2e1 * t299);
  t445 = my_piecewise3(t22, 0, 0.10e2 / 0.9e1 * t293 * t436 + 0.5e1 / 0.3e1 * t27 * t441);
  t446 = t445 * t31;
  t452 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t446 * t77 + t397 / 0.5e1 - t323);
  t453 = t206 * t206;
  t458 = my_piecewise5(t16, 0, t12, 0, -0.2e1 * t133 + 0.2e1 * t358);
  t462 = my_piecewise3(t87, 0, 0.10e2 / 0.9e1 * t354 * t453 + 0.5e1 / 0.3e1 * t89 * t458);
  t463 = t462 * t31;
  t473 = 0.1e1 / t95 / t113;
  t483 = sigma[2] * t231;
  t489 = 0.1e1 / t94 / t113 / t107;
  t493 = 0.55e2 / 0.729e3 * t38 * sigma[2] * t473 + 0.100e3 / 0.243e3 * t38 * lapl[1] * t215 + 0.65e2 / 0.26244e5 * t55 * t106 * t123 - 0.13e2 / 0.2916e4 * t55 * t483 * lapl[1] + 0.38e2 / 0.19683e5 * t55 * t120 * t489;
  t498 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t463 * t127 + t421 / 0.5e1 + 0.3e1 / 0.10e2 * t7 * t210 * t235 - t377 + t428 / 0.5e1 + 0.3e1 / 0.20e2 * t7 * t92 * t493);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rho2[2] = 0.2e1 * t204 + 0.2e1 * t240 + t8 * (t452 + t498);

  t506 = t7 * t145 * t250 / 0.10e2;
  t507 = t38 * t150;
  t510 = t55 * t73 * lapl[0];
  t512 = t55 * t338;
  t514 = -0.5e1 / 0.243e3 * t507 + 0.13e2 / 0.15552e5 * t510 - 0.4e1 / 0.6561e4 * t512;
  t519 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t140 * t250 + t506 + 0.3e1 / 0.20e2 * t7 * t32 * t514);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rhosigma[0] = t8 * t519 + t254;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rhosigma[1] = 0.0e0;

  t526 = t7 * t186 * t262 / 0.10e2;
  t528 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t182 * t262 + t526);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rhosigma[2] = t8 * t528 + t266;

  t534 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t199 * t250 + t506);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rhosigma[3] = t8 * t534 + t254;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rhosigma[4] = 0.0e0;

  t539 = t38 * t215;
  t542 = t55 * t123 * lapl[1];
  t544 = t55 * t483;
  t546 = -0.5e1 / 0.243e3 * t539 + 0.13e2 / 0.15552e5 * t542 - 0.4e1 / 0.6561e4 * t544;
  t551 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t210 * t262 + t526 + 0.3e1 / 0.20e2 * t7 * t92 * t546);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rhosigma[5] = t8 * t551 + t266;

  t558 = t7 * t145 * t274 / 0.10e2;
  t562 = -0.25e2 / 0.162e3 * t243 - 0.5e1 / 0.4374e4 * t246 + 0.13e2 / 0.15552e5 * t248;
  t567 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t140 * t274 + t558 + 0.3e1 / 0.20e2 * t7 * t32 * t562);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rholapl[0] = t8 * t567 + t278;

  t574 = t7 * t186 * t286 / 0.10e2;
  t576 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t182 * t286 + t574);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rholapl[1] = t8 * t576 + t290;

  t582 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t199 * t274 + t558);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rholapl[2] = t8 * t582 + t278;

  t590 = -0.25e2 / 0.162e3 * t255 - 0.5e1 / 0.4374e4 * t258 + 0.13e2 / 0.15552e5 * t260;
  t595 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t210 * t286 + t574 + 0.3e1 / 0.20e2 * t7 * t92 * t590);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rholapl[3] = t8 * t595 + t290;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rhotau[0] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rhotau[1] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rhotau[2] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2rhotau[3] = 0.0e0;

  t597 = t7 * t29;
  t598 = t31 * t52;
  t599 = t54 * t73;
  t600 = t598 * t599;
  t601 = t597 * t600;
  t603 = my_piecewise3(t2, 0, t601 / 0.58320e5);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigma2[0] = t8 * t603;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigma2[1] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigma2[2] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigma2[3] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigma2[4] = 0.0e0;

  t604 = t7 * t91;
  t605 = t54 * t123;
  t606 = t598 * t605;
  t607 = t604 * t606;
  t609 = my_piecewise3(t82, 0, t607 / 0.58320e5);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigma2[5] = t8 * t609;

  t610 = t54 * t65;
  t611 = t598 * t610;
  t612 = t597 * t611;
  t614 = my_piecewise3(t2, 0, -t612 / 0.34560e5);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmalapl[0] = t8 * t614;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmalapl[1] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmalapl[2] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmalapl[3] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmalapl[4] = 0.0e0;

  t615 = t54 * t115;
  t616 = t598 * t615;
  t617 = t604 * t616;
  t619 = my_piecewise3(t82, 0, -t617 / 0.34560e5);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmalapl[5] = t8 * t619;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmatau[0] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmatau[1] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmatau[2] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmatau[3] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmatau[4] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2sigmatau[5] = 0.0e0;

  t620 = t54 * t59;
  t621 = t598 * t620;
  t624 = my_piecewise3(t2, 0, t597 * t621 / 0.19440e5);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2lapl2[0] = t8 * t624;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2lapl2[1] = 0.0e0;

  t625 = t54 * t109;
  t626 = t598 * t625;
  t629 = my_piecewise3(t82, 0, t604 * t626 / 0.19440e5);
  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2lapl2[2] = t8 * t629;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2lapltau[0] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2lapltau[1] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2lapltau[2] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2lapltau[3] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2tau2[0] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2tau2[1] = 0.0e0;

  if(v2rho2 != NULL && (p->info->flags & XC_FLAGS_HAVE_FXC))
    v2tau2[2] = 0.0e0;

#ifndef XC_DONT_COMPILE_KXC

  if(order < 3) return;


  t633 = 0.1e1 / t26 / t21;
  t634 = t294 * t136;
  t637 = t293 * t136;
  t640 = t132 * t132;
  t641 = 0.1e1 / t640;
  t642 = t18 * t641;
  t645 = my_piecewise5(t12, 0, t16, 0, 0.6e1 * t298 - 0.6e1 * t642);
  t649 = my_piecewise3(t22, 0, -0.10e2 / 0.27e2 * t633 * t634 + 0.10e2 / 0.3e1 * t637 * t302 + 0.5e1 / 0.3e1 * t27 * t645);
  t650 = t649 * t31;
  t654 = t306 * t144;
  t656 = t7 * t654 * t77;
  t661 = t139 * t319;
  t663 = t7 * t661 * t77;
  t666 = t7 * t311 * t170;
  t672 = 0.1e1 / t30 / t132;
  t673 = t29 * t672;
  t676 = 0.2e1 / 0.45e2 * t7 * t673 * t77;
  t678 = t7 * t320 * t170;
  t681 = t7 * t145 * t348;
  t684 = 0.1e1 / t41 / t71;
  t694 = sigma[0] * t344;
  t698 = t63 * t63;
  t700 = 0.1e1 / t40 / t698;
  t704 = -0.770e3 / 0.2187e4 * t38 * sigma[0] * t684 - 0.1100e4 / 0.729e3 * t38 * lapl[0] * t328 - 0.260e3 / 0.19683e5 * t55 * t56 * t166 + 0.247e3 / 0.8748e4 * t55 * t694 * lapl[0] - 0.836e3 / 0.59049e5 * t55 * t70 * t700;
  t709 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t650 * t77 + 0.3e1 / 0.10e2 * t656 + 0.9e1 / 0.20e2 * t7 * t307 * t170 - t663 / 0.10e2 + 0.3e1 / 0.5e1 * t666 + 0.9e1 / 0.20e2 * t7 * t140 * t348 + t676 - t678 / 0.10e2 + 0.3e1 / 0.10e2 * t681 + 0.3e1 / 0.20e2 * t7 * t32 * t704);
  t711 = 0.1e1 / t88 / t86;
  t712 = t355 * t178;
  t715 = t354 * t178;
  t718 = t83 * t641;
  t721 = my_piecewise5(t16, 0, t12, 0, -0.6e1 * t298 - 0.6e1 * t718);
  t725 = my_piecewise3(t87, 0, -0.10e2 / 0.27e2 * t711 * t712 + 0.10e2 / 0.3e1 * t715 * t361 + 0.5e1 / 0.3e1 * t89 * t721);
  t726 = t725 * t31;
  t730 = t365 * t144;
  t732 = t7 * t730 * t127;
  t734 = t181 * t319;
  t736 = t7 * t734 * t127;
  t738 = t91 * t672;
  t741 = 0.2e1 / 0.45e2 * t7 * t738 * t127;
  t743 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t726 * t127 + 0.3e1 / 0.10e2 * t732 - t736 / 0.10e2 + t741);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho3[0] = 0.3e1 * t353 + 0.3e1 * t379 + t8 * (t709 + t743);

  t746 = 0.2e1 * t405;
  t747 = 0.2e1 * t431;
  t748 = t633 * t195;
  t751 = t293 * t386;
  t756 = 0.2e1 * t298;
  t757 = 0.6e1 * t642;
  t759 = my_piecewise5(t12, 0, t16, 0, t756 - t757);
  t763 = my_piecewise3(t22, 0, -0.10e2 / 0.27e2 * t748 * t294 + 0.20e2 / 0.9e1 * t751 * t136 + 0.10e2 / 0.9e1 * t382 * t302 + 0.5e1 / 0.3e1 * t27 * t759);
  t764 = t763 * t31;
  t768 = t390 * t144;
  t771 = t7 * t768 * t77 / 0.5e1;
  t775 = t198 * t319;
  t777 = t7 * t775 * t77;
  t781 = t7 * t395 * t170 / 0.5e1;
  t790 = 0.3e1 / 0.20e2 * t7 * t764 * t77 + t771 + 0.3e1 / 0.10e2 * t7 * t391 * t170 - t777 / 0.30e2 + t781 + 0.3e1 / 0.20e2 * t7 * t199 * t348 + t656 / 0.10e2 - t663 / 0.15e2 + t666 / 0.5e1 + t676 - t678 / 0.15e2 + t681 / 0.10e2;
  t791 = my_piecewise3(t2, 0, t790);
  t792 = t711 * t206;
  t795 = t354 * t410;
  t800 = 0.6e1 * t718;
  t802 = my_piecewise5(t16, 0, t12, 0, -t756 - t800);
  t806 = my_piecewise3(t87, 0, -0.10e2 / 0.27e2 * t792 * t355 + 0.20e2 / 0.9e1 * t795 * t178 + 0.10e2 / 0.9e1 * t406 * t361 + 0.5e1 / 0.3e1 * t89 * t802);
  t807 = t806 * t31;
  t811 = t414 * t144;
  t814 = t7 * t811 * t127 / 0.5e1;
  t815 = t209 * t319;
  t817 = t7 * t815 * t127;
  t826 = t7 * t370 * t235 / 0.5e1;
  t828 = t7 * t374 * t235;
  t831 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t807 * t127 + t814 - t817 / 0.30e2 + t732 / 0.10e2 - t736 / 0.15e2 + t741 + 0.3e1 / 0.20e2 * t7 * t366 * t235 + t826 - t828 / 0.30e2);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho3[1] = t353 + t379 + t746 + t747 + t8 * (t791 + t831);

  t834 = t633 * t436;
  t839 = t293 * t441;
  t843 = my_piecewise5(t12, 0, t16, 0, -t756 - t757);
  t847 = my_piecewise3(t22, 0, -0.10e2 / 0.27e2 * t834 * t136 + 0.20e2 / 0.9e1 * t382 * t386 + 0.10e2 / 0.9e1 * t839 * t136 + 0.5e1 / 0.3e1 * t27 * t843);
  t848 = t847 * t31;
  t852 = t445 * t144;
  t854 = t7 * t852 * t77;
  t863 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t848 * t77 + t854 / 0.10e2 + 0.3e1 / 0.20e2 * t7 * t446 * t170 + t771 - t777 / 0.15e2 + t781 - t663 / 0.30e2 + t676 - t678 / 0.30e2);
  t864 = t711 * t453;
  t869 = t354 * t458;
  t873 = my_piecewise5(t16, 0, t12, 0, t756 - t800);
  t877 = my_piecewise3(t87, 0, -0.10e2 / 0.27e2 * t864 * t178 + 0.20e2 / 0.9e1 * t406 * t410 + 0.10e2 / 0.9e1 * t869 * t178 + 0.5e1 / 0.3e1 * t89 * t873);
  t878 = t877 * t31;
  t882 = t462 * t144;
  t884 = t7 * t882 * t127;
  t891 = t7 * t419 * t235;
  t899 = t7 * t186 * t493;
  t901 = 0.3e1 / 0.20e2 * t7 * t878 * t127 + t884 / 0.10e2 + t814 - t817 / 0.15e2 + 0.3e1 / 0.10e2 * t7 * t415 * t235 + t891 / 0.5e1 - t736 / 0.30e2 + t741 + t826 - t828 / 0.15e2 + 0.3e1 / 0.20e2 * t7 * t182 * t493 + t899 / 0.10e2;
  t902 = my_piecewise3(t82, 0, t901);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho3[2] = t746 + t747 + t452 + t498 + t8 * (t863 + t902);

  t907 = t436 * t195;
  t914 = my_piecewise5(t12, 0, t16, 0, -0.6e1 * t298 - 0.6e1 * t642);
  t918 = my_piecewise3(t22, 0, -0.10e2 / 0.27e2 * t633 * t907 + 0.10e2 / 0.3e1 * t382 * t441 + 0.5e1 / 0.3e1 * t27 * t914);
  t919 = t918 * t31;
  t926 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t919 * t77 + 0.3e1 / 0.10e2 * t854 - t777 / 0.10e2 + t676);
  t927 = t453 * t206;
  t934 = my_piecewise5(t16, 0, t12, 0, 0.6e1 * t298 - 0.6e1 * t718);
  t938 = my_piecewise3(t87, 0, -0.10e2 / 0.27e2 * t711 * t927 + 0.10e2 / 0.3e1 * t406 * t458 + 0.5e1 / 0.3e1 * t89 * t934);
  t939 = t938 * t31;
  t955 = 0.1e1 / t95 / t121;
  t965 = sigma[2] * t489;
  t969 = t113 * t113;
  t971 = 0.1e1 / t94 / t969;
  t975 = -0.770e3 / 0.2187e4 * t38 * sigma[2] * t955 - 0.1100e4 / 0.729e3 * t38 * lapl[1] * t473 - 0.260e3 / 0.19683e5 * t55 * t106 * t231 + 0.247e3 / 0.8748e4 * t55 * t965 * lapl[1] - 0.836e3 / 0.59049e5 * t55 * t120 * t971;
  t980 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t939 * t127 + 0.3e1 / 0.10e2 * t884 + 0.9e1 / 0.20e2 * t7 * t463 * t235 - t817 / 0.10e2 + 0.3e1 / 0.5e1 * t891 + 0.9e1 / 0.20e2 * t7 * t210 * t493 + t741 - t828 / 0.10e2 + 0.3e1 / 0.10e2 * t899 + 0.3e1 / 0.20e2 * t7 * t92 * t975);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho3[3] = 0.3e1 * t452 + 0.3e1 * t498 + t8 * (t926 + t980);

  t988 = t7 * t311 * t250;
  t995 = t7 * t320 * t250 / 0.30e2;
  t997 = t7 * t145 * t514;
  t999 = t38 * t328;
  t1002 = t55 * t166 * lapl[0];
  t1004 = t55 * t694;
  t1006 = 0.55e2 / 0.729e3 * t999 - 0.13e2 / 0.2916e4 * t1002 + 0.76e2 / 0.19683e5 * t1004;
  t1011 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t307 * t250 + t988 / 0.5e1 + 0.3e1 / 0.10e2 * t7 * t140 * t514 - t995 + t997 / 0.5e1 + 0.3e1 / 0.20e2 * t7 * t32 * t1006);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2sigma[0] = t8 * t1011 + 0.2e1 * t519;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2sigma[1] = 0.0e0;

  t1018 = t7 * t370 * t262;
  t1022 = t7 * t374 * t262 / 0.30e2;
  t1024 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t366 * t262 + t1018 / 0.5e1 - t1022);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2sigma[2] = t8 * t1024 + 0.2e1 * t528;

  t1030 = t7 * t395 * t250;
  t1038 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t391 * t250 + t1030 / 0.10e2 + 0.3e1 / 0.20e2 * t7 * t199 * t514 + t988 / 0.10e2 - t995 + t997 / 0.10e2);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2sigma[3] = t8 * t1038 + t519 + t534;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2sigma[4] = 0.0e0;

  t1044 = t7 * t419 * t262;
  t1051 = t7 * t186 * t546;
  t1054 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t415 * t262 + t1044 / 0.10e2 + t1018 / 0.10e2 - t1022 + 0.3e1 / 0.20e2 * t7 * t182 * t546 + t1051 / 0.10e2);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2sigma[5] = t8 * t1054 + t528 + t551;

  t1062 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t446 * t250 + t1030 / 0.5e1 - t995);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2sigma[6] = t8 * t1062 + 0.2e1 * t534;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2sigma[7] = 0.0e0;

  t1073 = t38 * t473;
  t1076 = t55 * t231 * lapl[1];
  t1078 = t55 * t965;
  t1080 = 0.55e2 / 0.729e3 * t1073 - 0.13e2 / 0.2916e4 * t1076 + 0.76e2 / 0.19683e5 * t1078;
  t1085 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t463 * t262 + t1044 / 0.5e1 + 0.3e1 / 0.10e2 * t7 * t210 * t546 - t1022 + t1051 / 0.5e1 + 0.3e1 / 0.20e2 * t7 * t92 * t1080);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2sigma[8] = t8 * t1085 + 0.2e1 * t551;

  t1092 = t7 * t311 * t274;
  t1099 = t7 * t320 * t274 / 0.30e2;
  t1101 = t7 * t145 * t562;
  t1106 = 0.100e3 / 0.243e3 * t507 + 0.65e2 / 0.13122e5 * t510 - 0.13e2 / 0.2916e4 * t512;
  t1111 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t307 * t274 + t1092 / 0.5e1 + 0.3e1 / 0.10e2 * t7 * t140 * t562 - t1099 + t1101 / 0.5e1 + 0.3e1 / 0.20e2 * t7 * t32 * t1106);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2lapl[0] = t8 * t1111 + 0.2e1 * t567;

  t1118 = t7 * t370 * t286;
  t1122 = t7 * t374 * t286 / 0.30e2;
  t1124 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t366 * t286 + t1118 / 0.5e1 - t1122);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2lapl[1] = t8 * t1124 + 0.2e1 * t576;

  t1130 = t7 * t395 * t274;
  t1138 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t391 * t274 + t1130 / 0.10e2 + 0.3e1 / 0.20e2 * t7 * t199 * t562 + t1092 / 0.10e2 - t1099 + t1101 / 0.10e2);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2lapl[2] = t8 * t1138 + t567 + t582;

  t1144 = t7 * t419 * t286;
  t1151 = t7 * t186 * t590;
  t1154 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t415 * t286 + t1144 / 0.10e2 + t1118 / 0.10e2 - t1122 + 0.3e1 / 0.20e2 * t7 * t182 * t590 + t1151 / 0.10e2);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2lapl[3] = t8 * t1154 + t576 + t595;

  t1162 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t446 * t274 + t1130 / 0.5e1 - t1099);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2lapl[4] = t8 * t1162 + 0.2e1 * t582;

  t1176 = 0.100e3 / 0.243e3 * t539 + 0.65e2 / 0.13122e5 * t542 - 0.13e2 / 0.2916e4 * t544;
  t1181 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t463 * t286 + t1144 / 0.5e1 + 0.3e1 / 0.10e2 * t7 * t210 * t590 - t1122 + t1151 / 0.5e1 + 0.3e1 / 0.20e2 * t7 * t92 * t1176);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2lapl[5] = t8 * t1181 + 0.2e1 * t595;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2tau[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2tau[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2tau[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2tau[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2tau[4] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rho2tau[5] = 0.0e0;

  t1183 = t7 * t139;
  t1184 = t1183 * t600;
  t1186 = t144 * t52;
  t1187 = t1186 * t599;
  t1188 = t597 * t1187;
  t1189 = t1188 / 0.87480e5;
  t1190 = t54 * t166;
  t1191 = t598 * t1190;
  t1192 = t597 * t1191;
  t1195 = my_piecewise3(t2, 0, t1184 / 0.58320e5 + t1189 - t1192 / 0.10935e5);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[0] = t8 * t1195 + t603;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[4] = 0.0e0;

  t1197 = t7 * t181;
  t1198 = t1197 * t606;
  t1200 = t1186 * t605;
  t1201 = t604 * t1200;
  t1202 = t1201 / 0.87480e5;
  t1204 = my_piecewise3(t82, 0, t1198 / 0.58320e5 + t1202);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[5] = t8 * t1204 + t609;

  t1206 = t7 * t198;
  t1207 = t1206 * t600;
  t1210 = my_piecewise3(t2, 0, t1207 / 0.58320e5 + t1189);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[6] = t8 * t1210 + t603;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[7] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[8] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[9] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[10] = 0.0e0;

  t1212 = t7 * t209;
  t1213 = t1212 * t606;
  t1215 = t54 * t231;
  t1216 = t598 * t1215;
  t1217 = t604 * t1216;
  t1220 = my_piecewise3(t82, 0, t1213 / 0.58320e5 + t1202 - t1217 / 0.10935e5);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigma2[11] = t8 * t1220 + t609;

  t1222 = t1183 * t611;
  t1224 = t1186 * t610;
  t1225 = t597 * t1224;
  t1226 = t1225 / 0.51840e5;
  t1229 = my_piecewise3(t2, 0, -t1222 / 0.34560e5 - t1226 + 0.13e2 / 0.103680e6 * t601);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[0] = t8 * t1229 + t614;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[4] = 0.0e0;

  t1231 = t1197 * t616;
  t1233 = t1186 * t615;
  t1234 = t604 * t1233;
  t1235 = t1234 / 0.51840e5;
  t1237 = my_piecewise3(t82, 0, -t1231 / 0.34560e5 - t1235);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[5] = t8 * t1237 + t619;

  t1239 = t1206 * t611;
  t1242 = my_piecewise3(t2, 0, -t1239 / 0.34560e5 - t1226);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[6] = t8 * t1242 + t614;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[7] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[8] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[9] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[10] = 0.0e0;

  t1244 = t1212 * t616;
  t1248 = my_piecewise3(t82, 0, -t1244 / 0.34560e5 - t1235 + 0.13e2 / 0.103680e6 * t607);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmalapl[11] = t8 * t1248 + t619;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[4] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[5] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[6] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[7] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[8] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[9] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[10] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhosigmatau[11] = 0.0e0;

  t1252 = t1186 * t620;
  t1254 = t597 * t1252 / 0.29160e5;
  t1257 = my_piecewise3(t2, 0, t1183 * t621 / 0.19440e5 + t1254 - t612 / 0.5832e4);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapl2[0] = t8 * t1257 + t624;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapl2[1] = 0.0e0;

  t1261 = t1186 * t625;
  t1263 = t604 * t1261 / 0.29160e5;
  t1265 = my_piecewise3(t82, 0, t1197 * t626 / 0.19440e5 + t1263);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapl2[2] = t8 * t1265 + t629;

  t1270 = my_piecewise3(t2, 0, t1206 * t621 / 0.19440e5 + t1254);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapl2[3] = t8 * t1270 + t624;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapl2[4] = 0.0e0;

  t1276 = my_piecewise3(t82, 0, t1212 * t626 / 0.19440e5 + t1263 - t617 / 0.5832e4);
  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapl2[5] = t8 * t1276 + t629;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapltau[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapltau[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapltau[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapltau[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapltau[4] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapltau[5] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapltau[6] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rholapltau[7] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhotau2[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhotau2[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhotau2[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhotau2[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhotau2[4] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3rhotau2[5] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma3[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma3[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma3[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma3[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma3[4] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma3[5] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma3[6] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma3[7] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma3[8] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma3[9] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[4] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[5] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[6] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[7] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[8] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[9] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[10] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2lapl[11] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[4] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[5] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[6] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[7] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[8] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[9] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[10] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigma2tau[11] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapl2[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapl2[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapl2[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapl2[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapl2[4] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapl2[5] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapl2[6] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapl2[7] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapl2[8] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[4] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[5] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[6] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[7] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[8] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[9] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[10] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmalapltau[11] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmatau2[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmatau2[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmatau2[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmatau2[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmatau2[4] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmatau2[5] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmatau2[6] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmatau2[7] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3sigmatau2[8] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapl3[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapl3[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapl3[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapl3[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapl2tau[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapl2tau[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapl2tau[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapl2tau[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapl2tau[4] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapl2tau[5] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapltau2[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapltau2[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapltau2[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapltau2[3] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapltau2[4] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3lapltau2[5] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3tau3[0] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3tau3[1] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3tau3[2] = 0.0e0;

  if(v3rho3 != NULL && (p->info->flags & XC_FLAGS_HAVE_KXC))
    v3tau3[3] = 0.0e0;

#ifndef XC_DONT_COMPILE_LXC

  if(order < 4) return;


  t1282 = t7 * t649 * t144 * t77;
  t1286 = t7 * t306 * t319 * t77;
  t1290 = t7 * t139 * t672 * t77;
  t1293 = 0.1e1 / t30 / t297;
  t1297 = 0.14e2 / 0.135e3 * t7 * t29 * t1293 * t77;
  t1298 = t21 * t21;
  t1300 = 0.1e1 / t26 / t1298;
  t1301 = t294 * t294;
  t1307 = t302 * t302;
  t1313 = 0.1e1 / t640 / t8;
  t1314 = t18 * t1313;
  t1317 = my_piecewise5(t12, 0, t16, 0, -0.24e2 * t641 + 0.24e2 * t1314);
  t1321 = my_piecewise3(t22, 0, 0.40e2 / 0.81e2 * t1300 * t1301 - 0.20e2 / 0.9e1 * t633 * t294 * t302 + 0.10e2 / 0.3e1 * t293 * t1307 + 0.40e2 / 0.9e1 * t637 * t645 + 0.5e1 / 0.3e1 * t27 * t1317);
  t1330 = t7 * t654 * t170;
  t1336 = t7 * t661 * t170;
  t1339 = t7 * t311 * t348;
  t1345 = t7 * t673 * t170;
  t1348 = t7 * t320 * t348;
  t1351 = t7 * t145 * t704;
  t1364 = sigma[0] * t700;
  t1378 = 0.2e1 / 0.5e1 * t1282 - t1286 / 0.5e1 + 0.8e1 / 0.45e2 * t1290 - t1297 + 0.3e1 / 0.20e2 * t7 * t1321 * t31 * t77 + 0.3e1 / 0.5e1 * t7 * t650 * t170 + 0.6e1 / 0.5e1 * t1330 + 0.9e1 / 0.10e2 * t7 * t307 * t348 - 0.2e1 / 0.5e1 * t1336 + 0.6e1 / 0.5e1 * t1339 + 0.3e1 / 0.5e1 * t7 * t140 * t704 + 0.8e1 / 0.45e2 * t1345 - t1348 / 0.5e1 + 0.2e1 / 0.5e1 * t1351 + 0.3e1 / 0.20e2 * t7 * t32 * (0.13090e5 / 0.6561e4 * t38 * sigma[0] / t41 / t164 + 0.15400e5 / 0.2187e4 * t38 * lapl[0] * t684 + 0.4940e4 / 0.59049e5 * t55 * t56 * t344 - 0.2717e4 / 0.13122e5 * t55 * t1364 * lapl[0] + 0.20900e5 / 0.177147e6 * t55 * t70 / t40 / t698 / rho[0]);
  t1379 = my_piecewise3(t2, 0, t1378);
  t1380 = t86 * t86;
  t1382 = 0.1e1 / t88 / t1380;
  t1383 = t355 * t355;
  t1389 = t361 * t361;
  t1394 = t83 * t1313;
  t1397 = my_piecewise5(t16, 0, t12, 0, 0.24e2 * t641 + 0.24e2 * t1394);
  t1401 = my_piecewise3(t87, 0, 0.40e2 / 0.81e2 * t1382 * t1383 - 0.20e2 / 0.9e1 * t711 * t355 * t361 + 0.10e2 / 0.3e1 * t354 * t1389 + 0.40e2 / 0.9e1 * t715 * t721 + 0.5e1 / 0.3e1 * t89 * t1397);
  t1408 = t7 * t725 * t144 * t127;
  t1412 = t7 * t365 * t319 * t127;
  t1416 = t7 * t181 * t672 * t127;
  t1421 = 0.14e2 / 0.135e3 * t7 * t91 * t1293 * t127;
  t1423 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t1401 * t31 * t127 + 0.2e1 / 0.5e1 * t1408 - t1412 / 0.5e1 + 0.8e1 / 0.45e2 * t1416 - t1421);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho4[0] = 0.4e1 * t709 + 0.4e1 * t743 + t8 * (t1379 + t1423);

  t1429 = t7 * t775 * t170;
  t1430 = t1429 / 0.10e2;
  t1432 = t7 * t395 * t348;
  t1453 = 0.12e2 * t641;
  t1454 = 0.24e2 * t1314;
  t1456 = my_piecewise5(t12, 0, t16, 0, -t1453 + t1454);
  t1460 = my_piecewise3(t22, 0, 0.40e2 / 0.81e2 * t1300 * t195 * t634 - 0.10e2 / 0.9e1 * t633 * t386 * t294 - 0.10e2 / 0.9e1 * t748 * t136 * t302 + 0.10e2 / 0.3e1 * t293 * t759 * t136 + 0.10e2 / 0.3e1 * t751 * t302 + 0.10e2 / 0.9e1 * t382 * t645 + 0.5e1 / 0.3e1 * t27 * t1456);
  t1469 = t7 * t768 * t170;
  t1476 = t7 * t763 * t144 * t77;
  t1480 = t7 * t390 * t319 * t77;
  t1481 = t1480 / 0.10e2;
  t1484 = t7 * t198 * t672 * t77;
  t1495 = -t1430 + 0.3e1 / 0.10e2 * t1432 + 0.3e1 / 0.20e2 * t7 * t199 * t704 + 0.3e1 / 0.20e2 * t7 * t1460 * t31 * t77 + 0.9e1 / 0.20e2 * t7 * t764 * t170 + 0.3e1 / 0.5e1 * t1469 + 0.9e1 / 0.20e2 * t7 * t391 * t348 + 0.3e1 / 0.10e2 * t1476 - t1481 + 0.2e1 / 0.45e2 * t1484 + t1282 / 0.10e2 - t1286 / 0.10e2 + 0.2e1 / 0.15e2 * t1290 - t1297 + 0.3e1 / 0.10e2 * t1330 - t1336 / 0.5e1 + 0.3e1 / 0.10e2 * t1339 + 0.2e1 / 0.15e2 * t1345 - t1348 / 0.10e2 + t1351 / 0.10e2;
  t1496 = my_piecewise3(t2, 0, t1495);
  t1513 = 0.24e2 * t1394;
  t1515 = my_piecewise5(t16, 0, t12, 0, t1453 + t1513);
  t1519 = my_piecewise3(t87, 0, 0.40e2 / 0.81e2 * t1382 * t206 * t712 - 0.10e2 / 0.9e1 * t711 * t410 * t355 - 0.10e2 / 0.9e1 * t792 * t178 * t361 + 0.10e2 / 0.3e1 * t354 * t802 * t178 + 0.10e2 / 0.3e1 * t795 * t361 + 0.10e2 / 0.9e1 * t406 * t721 + 0.5e1 / 0.3e1 * t89 * t1515);
  t1526 = t7 * t806 * t144 * t127;
  t1530 = t7 * t414 * t319 * t127;
  t1531 = t1530 / 0.10e2;
  t1534 = t7 * t209 * t672 * t127;
  t1543 = t7 * t730 * t235;
  t1546 = t7 * t734 * t235;
  t1547 = t1546 / 0.10e2;
  t1549 = t7 * t738 * t235;
  t1551 = 0.3e1 / 0.20e2 * t7 * t1519 * t31 * t127 + 0.3e1 / 0.10e2 * t1526 - t1531 + 0.2e1 / 0.45e2 * t1534 + t1408 / 0.10e2 - t1412 / 0.10e2 + 0.2e1 / 0.15e2 * t1416 - t1421 + 0.3e1 / 0.20e2 * t7 * t726 * t235 + 0.3e1 / 0.10e2 * t1543 - t1547 + 0.2e1 / 0.45e2 * t1549;
  t1552 = my_piecewise3(t82, 0, t1551);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho4[1] = t709 + t743 + 0.3e1 * t791 + 0.3e1 * t831 + t8 * (t1496 + t1552);

  t1567 = t386 * t386;
  t1580 = my_piecewise5(t12, 0, t16, 0, t1454);
  t1584 = my_piecewise3(t22, 0, 0.40e2 / 0.81e2 * t1300 * t436 * t294 - 0.40e2 / 0.27e2 * t748 * t136 * t386 - 0.10e2 / 0.27e2 * t834 * t302 + 0.20e2 / 0.9e1 * t293 * t1567 + 0.20e2 / 0.9e1 * t382 * t759 - 0.10e2 / 0.27e2 * t633 * t441 * t294 + 0.20e2 / 0.9e1 * t293 * t843 * t136 + 0.10e2 / 0.9e1 * t839 * t302 + 0.5e1 / 0.3e1 * t27 * t1580);
  t1593 = t7 * t852 * t170;
  t1603 = t7 * t847 * t144 * t77;
  t1607 = t7 * t445 * t319 * t77;
  t1617 = 0.3e1 / 0.20e2 * t7 * t1584 * t31 * t77 + 0.3e1 / 0.10e2 * t7 * t848 * t170 + t1593 / 0.5e1 + 0.3e1 / 0.20e2 * t7 * t446 * t348 - 0.2e1 / 0.15e2 * t1429 + t1432 / 0.5e1 + 0.2e1 / 0.5e1 * t1469 + t1603 / 0.5e1 - t1607 / 0.30e2 + t1476 / 0.5e1 - 0.2e1 / 0.15e2 * t1480 + 0.4e1 / 0.45e2 * t1484 - t1286 / 0.30e2 + 0.4e1 / 0.45e2 * t1290 - t1297 - t1336 / 0.15e2 + 0.4e1 / 0.45e2 * t1345 - t1348 / 0.30e2;
  t1618 = my_piecewise3(t2, 0, t1617);
  t1627 = t410 * t410;
  t1640 = my_piecewise5(t16, 0, t12, 0, t1513);
  t1644 = my_piecewise3(t87, 0, 0.40e2 / 0.81e2 * t1382 * t453 * t355 - 0.40e2 / 0.27e2 * t792 * t178 * t410 - 0.10e2 / 0.27e2 * t864 * t361 + 0.20e2 / 0.9e1 * t354 * t1627 + 0.20e2 / 0.9e1 * t406 * t802 - 0.10e2 / 0.27e2 * t711 * t458 * t355 + 0.20e2 / 0.9e1 * t354 * t873 * t178 + 0.10e2 / 0.9e1 * t869 * t361 + 0.5e1 / 0.3e1 * t89 * t1640);
  t1651 = t7 * t877 * t144 * t127;
  t1655 = t7 * t462 * t319 * t127;
  t1664 = t7 * t811 * t235;
  t1667 = t7 * t815 * t235;
  t1678 = t7 * t370 * t493;
  t1681 = t7 * t374 * t493;
  t1683 = 0.3e1 / 0.20e2 * t7 * t1644 * t31 * t127 + t1651 / 0.5e1 - t1655 / 0.30e2 + t1526 / 0.5e1 - 0.2e1 / 0.15e2 * t1530 + 0.4e1 / 0.45e2 * t1534 + 0.3e1 / 0.10e2 * t7 * t807 * t235 + 0.2e1 / 0.5e1 * t1664 - t1667 / 0.15e2 - t1412 / 0.30e2 + 0.4e1 / 0.45e2 * t1416 - t1421 + t1543 / 0.5e1 - 0.2e1 / 0.15e2 * t1546 + 0.4e1 / 0.45e2 * t1549 + 0.3e1 / 0.20e2 * t7 * t366 * t493 + t1678 / 0.5e1 - t1681 / 0.30e2;
  t1684 = my_piecewise3(t82, 0, t1683);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho4[2] = 0.2e1 * t791 + 0.2e1 * t831 + 0.2e1 * t863 + 0.2e1 * t902 + t8 * (t1618 + t1684);

  t1705 = my_piecewise5(t12, 0, t16, 0, t1453 + t1454);
  t1709 = my_piecewise3(t22, 0, 0.40e2 / 0.81e2 * t1300 * t907 * t136 - 0.10e2 / 0.9e1 * t834 * t386 - 0.10e2 / 0.9e1 * t748 * t441 * t136 + 0.10e2 / 0.3e1 * t751 * t441 + 0.10e2 / 0.3e1 * t382 * t843 + 0.10e2 / 0.9e1 * t293 * t914 * t136 + 0.5e1 / 0.3e1 * t27 * t1705);
  t1716 = t7 * t918 * t144 * t77;
  t1727 = 0.3e1 / 0.20e2 * t7 * t1709 * t31 * t77 + t1716 / 0.10e2 + 0.3e1 / 0.20e2 * t7 * t919 * t170 + 0.3e1 / 0.10e2 * t1603 - t1607 / 0.10e2 + 0.3e1 / 0.10e2 * t1593 - t1481 + 0.2e1 / 0.15e2 * t1484 - t1430 + 0.2e1 / 0.45e2 * t1290 - t1297 + 0.2e1 / 0.45e2 * t1345;
  t1728 = my_piecewise3(t2, 0, t1727);
  t1745 = my_piecewise5(t16, 0, t12, 0, -t1453 + t1513);
  t1749 = my_piecewise3(t87, 0, 0.40e2 / 0.81e2 * t1382 * t927 * t178 - 0.10e2 / 0.9e1 * t864 * t410 - 0.10e2 / 0.9e1 * t792 * t458 * t178 + 0.10e2 / 0.3e1 * t795 * t458 + 0.10e2 / 0.3e1 * t406 * t873 + 0.10e2 / 0.9e1 * t354 * t934 * t178 + 0.5e1 / 0.3e1 * t89 * t1745);
  t1756 = t7 * t938 * t144 * t127;
  t1764 = t7 * t882 * t235;
  t1773 = t7 * t419 * t493;
  t1783 = t7 * t186 * t975;
  t1785 = 0.3e1 / 0.20e2 * t7 * t1749 * t31 * t127 + t1756 / 0.10e2 + 0.3e1 / 0.10e2 * t1651 - t1655 / 0.10e2 + 0.9e1 / 0.20e2 * t7 * t878 * t235 + 0.3e1 / 0.10e2 * t1764 - t1531 + 0.2e1 / 0.15e2 * t1534 + 0.3e1 / 0.5e1 * t1664 - t1667 / 0.5e1 + 0.9e1 / 0.20e2 * t7 * t415 * t493 + 0.3e1 / 0.10e2 * t1773 + 0.2e1 / 0.45e2 * t1416 - t1421 - t1547 + 0.2e1 / 0.15e2 * t1549 + 0.3e1 / 0.10e2 * t1678 - t1681 / 0.10e2 + 0.3e1 / 0.20e2 * t7 * t182 * t975 + t1783 / 0.10e2;
  t1786 = my_piecewise3(t82, 0, t1785);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho4[3] = 0.3e1 * t863 + 0.3e1 * t902 + t926 + t980 + t8 * (t1728 + t1786);

  t1791 = t436 * t436;
  t1796 = t441 * t441;
  t1803 = my_piecewise5(t12, 0, t16, 0, 0.24e2 * t641 + 0.24e2 * t1314);
  t1807 = my_piecewise3(t22, 0, 0.40e2 / 0.81e2 * t1300 * t1791 - 0.20e2 / 0.9e1 * t834 * t441 + 0.10e2 / 0.3e1 * t293 * t1796 + 0.40e2 / 0.9e1 * t382 * t914 + 0.5e1 / 0.3e1 * t27 * t1803);
  t1816 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t1807 * t31 * t77 + 0.2e1 / 0.5e1 * t1716 - t1607 / 0.5e1 + 0.8e1 / 0.45e2 * t1484 - t1297);
  t1817 = t453 * t453;
  t1822 = t458 * t458;
  t1829 = my_piecewise5(t16, 0, t12, 0, -0.24e2 * t641 + 0.24e2 * t1394);
  t1833 = my_piecewise3(t87, 0, 0.40e2 / 0.81e2 * t1382 * t1817 - 0.20e2 / 0.9e1 * t864 * t458 + 0.10e2 / 0.3e1 * t354 * t1822 + 0.40e2 / 0.9e1 * t406 * t934 + 0.5e1 / 0.3e1 * t89 * t1829);
  t1858 = sigma[2] * t971;
  t1881 = 0.3e1 / 0.20e2 * t7 * t1833 * t31 * t127 + 0.3e1 / 0.5e1 * t7 * t939 * t235 + 0.9e1 / 0.10e2 * t7 * t463 * t493 + 0.3e1 / 0.5e1 * t7 * t210 * t975 + 0.3e1 / 0.20e2 * t7 * t92 * (0.13090e5 / 0.6561e4 * t38 * sigma[2] / t95 / t229 + 0.15400e5 / 0.2187e4 * t38 * lapl[1] * t955 + 0.4940e4 / 0.59049e5 * t55 * t106 * t489 - 0.2717e4 / 0.13122e5 * t55 * t1858 * lapl[1] + 0.20900e5 / 0.177147e6 * t55 * t120 / t94 / t969 / rho[1]) + 0.6e1 / 0.5e1 * t1764 + 0.6e1 / 0.5e1 * t1773 + 0.2e1 / 0.5e1 * t1783 - t1655 / 0.5e1 - 0.2e1 / 0.5e1 * t1667 - t1681 / 0.5e1 + 0.2e1 / 0.5e1 * t1756 + 0.8e1 / 0.45e2 * t1534 + 0.8e1 / 0.45e2 * t1549 - t1421;
  t1882 = my_piecewise3(t82, 0, t1881);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho4[4] = 0.4e1 * t926 + 0.4e1 * t980 + t8 * (t1816 + t1882);

  t1890 = t7 * t654 * t250;
  t1896 = t7 * t661 * t250;
  t1899 = t7 * t311 * t514;
  t1906 = 0.2e1 / 0.45e2 * t7 * t673 * t250;
  t1908 = t7 * t320 * t514;
  t1911 = t7 * t145 * t1006;
  t1925 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t650 * t250 + 0.3e1 / 0.10e2 * t1890 + 0.9e1 / 0.20e2 * t7 * t307 * t514 - t1896 / 0.10e2 + 0.3e1 / 0.5e1 * t1899 + 0.9e1 / 0.20e2 * t7 * t140 * t1006 + t1906 - t1908 / 0.10e2 + 0.3e1 / 0.10e2 * t1911 + 0.3e1 / 0.20e2 * t7 * t32 * (-0.770e3 / 0.2187e4 * t38 * t684 + 0.247e3 / 0.8748e4 * t55 * t344 * lapl[0] - 0.1672e4 / 0.59049e5 * t55 * t1364));
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[0] = t8 * t1925 + 0.3e1 * t1011;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[1] = 0.0e0;

  t1932 = t7 * t730 * t262;
  t1935 = t7 * t734 * t262;
  t1939 = 0.2e1 / 0.45e2 * t7 * t738 * t262;
  t1941 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t726 * t262 + 0.3e1 / 0.10e2 * t1932 - t1935 / 0.10e2 + t1939);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[2] = t8 * t1941 + 0.3e1 * t1024;

  t1943 = 0.2e1 * t1038;
  t1949 = t7 * t768 * t250 / 0.5e1;
  t1954 = t7 * t775 * t250;
  t1958 = t7 * t395 * t514 / 0.5e1;
  t1967 = 0.3e1 / 0.20e2 * t7 * t764 * t250 + t1949 + 0.3e1 / 0.10e2 * t7 * t391 * t514 - t1954 / 0.30e2 + t1958 + 0.3e1 / 0.20e2 * t7 * t199 * t1006 + t1890 / 0.10e2 - t1896 / 0.15e2 + t1899 / 0.5e1 + t1906 - t1908 / 0.15e2 + t1911 / 0.10e2;
  t1968 = my_piecewise3(t2, 0, t1967);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[3] = t8 * t1968 + t1011 + t1943;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[4] = 0.0e0;

  t1970 = 0.2e1 * t1054;
  t1976 = t7 * t811 * t262 / 0.5e1;
  t1978 = t7 * t815 * t262;
  t1987 = t7 * t370 * t546 / 0.5e1;
  t1989 = t7 * t374 * t546;
  t1992 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t807 * t262 + t1976 - t1978 / 0.30e2 + t1932 / 0.10e2 - t1935 / 0.15e2 + t1939 + 0.3e1 / 0.20e2 * t7 * t366 * t546 + t1987 - t1989 / 0.30e2);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[5] = t8 * t1992 + t1024 + t1970;

  t1998 = t7 * t852 * t250;
  t2007 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t848 * t250 + t1998 / 0.10e2 + 0.3e1 / 0.20e2 * t7 * t446 * t514 + t1949 - t1954 / 0.15e2 + t1958 - t1896 / 0.30e2 + t1906 - t1908 / 0.30e2);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[6] = t8 * t2007 + t1062 + t1943;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[7] = 0.0e0;

  t2013 = t7 * t882 * t262;
  t2020 = t7 * t419 * t546;
  t2028 = t7 * t186 * t1080;
  t2030 = 0.3e1 / 0.20e2 * t7 * t878 * t262 + t2013 / 0.10e2 + t1976 - t1978 / 0.15e2 + 0.3e1 / 0.10e2 * t7 * t415 * t546 + t2020 / 0.5e1 - t1935 / 0.30e2 + t1939 + t1987 - t1989 / 0.15e2 + 0.3e1 / 0.20e2 * t7 * t182 * t1080 + t2028 / 0.10e2;
  t2031 = my_piecewise3(t82, 0, t2030);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[8] = t8 * t2031 + t1085 + t1970;

  t2040 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t919 * t250 + 0.3e1 / 0.10e2 * t1998 - t1954 / 0.10e2 + t1906);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[9] = t8 * t2040 + 0.3e1 * t1062;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[10] = 0.0e0;

  t2069 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t939 * t262 + 0.3e1 / 0.10e2 * t2013 + 0.9e1 / 0.20e2 * t7 * t463 * t546 - t1978 / 0.10e2 + 0.3e1 / 0.5e1 * t2020 + 0.9e1 / 0.20e2 * t7 * t210 * t1080 + t1939 - t1989 / 0.10e2 + 0.3e1 / 0.10e2 * t2028 + 0.3e1 / 0.20e2 * t7 * t92 * (-0.770e3 / 0.2187e4 * t38 * t955 + 0.247e3 / 0.8748e4 * t55 * t489 * lapl[1] - 0.1672e4 / 0.59049e5 * t55 * t1858));
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3sigma[11] = t8 * t2069 + 0.3e1 * t1085;

  t2076 = t7 * t654 * t274;
  t2082 = t7 * t661 * t274;
  t2085 = t7 * t311 * t562;
  t2092 = 0.2e1 / 0.45e2 * t7 * t673 * t274;
  t2094 = t7 * t320 * t562;
  t2097 = t7 * t145 * t1106;
  t2107 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t650 * t274 + 0.3e1 / 0.10e2 * t2076 + 0.9e1 / 0.20e2 * t7 * t307 * t562 - t2082 / 0.10e2 + 0.3e1 / 0.5e1 * t2085 + 0.9e1 / 0.20e2 * t7 * t140 * t1106 + t2092 - t2094 / 0.10e2 + 0.3e1 / 0.10e2 * t2097 + 0.3e1 / 0.20e2 * t7 * t32 * (-0.1100e4 / 0.729e3 * t999 - 0.520e3 / 0.19683e5 * t1002 + 0.247e3 / 0.8748e4 * t1004));
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3lapl[0] = t8 * t2107 + 0.3e1 * t1111;

  t2114 = t7 * t730 * t286;
  t2117 = t7 * t734 * t286;
  t2121 = 0.2e1 / 0.45e2 * t7 * t738 * t286;
  t2123 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t726 * t286 + 0.3e1 / 0.10e2 * t2114 - t2117 / 0.10e2 + t2121);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3lapl[1] = t8 * t2123 + 0.3e1 * t1124;

  t2125 = 0.2e1 * t1138;
  t2131 = t7 * t768 * t274 / 0.5e1;
  t2136 = t7 * t775 * t274;
  t2140 = t7 * t395 * t562 / 0.5e1;
  t2149 = 0.3e1 / 0.20e2 * t7 * t764 * t274 + t2131 + 0.3e1 / 0.10e2 * t7 * t391 * t562 - t2136 / 0.30e2 + t2140 + 0.3e1 / 0.20e2 * t7 * t199 * t1106 + t2076 / 0.10e2 - t2082 / 0.15e2 + t2085 / 0.5e1 + t2092 - t2094 / 0.15e2 + t2097 / 0.10e2;
  t2150 = my_piecewise3(t2, 0, t2149);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3lapl[2] = t8 * t2150 + t1111 + t2125;

  t2152 = 0.2e1 * t1154;
  t2158 = t7 * t811 * t286 / 0.5e1;
  t2160 = t7 * t815 * t286;
  t2169 = t7 * t370 * t590 / 0.5e1;
  t2171 = t7 * t374 * t590;
  t2174 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t807 * t286 + t2158 - t2160 / 0.30e2 + t2114 / 0.10e2 - t2117 / 0.15e2 + t2121 + 0.3e1 / 0.20e2 * t7 * t366 * t590 + t2169 - t2171 / 0.30e2);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3lapl[3] = t8 * t2174 + t1124 + t2152;

  t2180 = t7 * t852 * t274;
  t2189 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t848 * t274 + t2180 / 0.10e2 + 0.3e1 / 0.20e2 * t7 * t446 * t562 + t2131 - t2136 / 0.15e2 + t2140 - t2082 / 0.30e2 + t2092 - t2094 / 0.30e2);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3lapl[4] = t8 * t2189 + t1162 + t2125;

  t2195 = t7 * t882 * t286;
  t2202 = t7 * t419 * t590;
  t2210 = t7 * t186 * t1176;
  t2212 = 0.3e1 / 0.20e2 * t7 * t878 * t286 + t2195 / 0.10e2 + t2158 - t2160 / 0.15e2 + 0.3e1 / 0.10e2 * t7 * t415 * t590 + t2202 / 0.5e1 - t2117 / 0.30e2 + t2121 + t2169 - t2171 / 0.15e2 + 0.3e1 / 0.20e2 * t7 * t182 * t1176 + t2210 / 0.10e2;
  t2213 = my_piecewise3(t82, 0, t2212);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3lapl[5] = t8 * t2213 + t1181 + t2152;

  t2222 = my_piecewise3(t2, 0, 0.3e1 / 0.20e2 * t7 * t919 * t274 + 0.3e1 / 0.10e2 * t2180 - t2136 / 0.10e2 + t2092);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3lapl[6] = t8 * t2222 + 0.3e1 * t1162;

  t2247 = my_piecewise3(t82, 0, 0.3e1 / 0.20e2 * t7 * t939 * t286 + 0.3e1 / 0.10e2 * t2195 + 0.9e1 / 0.20e2 * t7 * t463 * t590 - t2160 / 0.10e2 + 0.3e1 / 0.5e1 * t2202 + 0.9e1 / 0.20e2 * t7 * t210 * t1176 + t2121 - t2171 / 0.10e2 + 0.3e1 / 0.10e2 * t2210 + 0.3e1 / 0.20e2 * t7 * t92 * (-0.1100e4 / 0.729e3 * t1073 - 0.520e3 / 0.19683e5 * t1076 + 0.247e3 / 0.8748e4 * t1078));
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3lapl[7] = t8 * t2247 + 0.3e1 * t1181;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3tau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3tau[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3tau[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3tau[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3tau[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3tau[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3tau[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho3tau[7] = 0.0e0;

  t2250 = t7 * t306;
  t2253 = t1183 * t1187;
  t2257 = t319 * t52;
  t2260 = t597 * t2257 * t599 / 0.262440e6;
  t2262 = t597 * t1186 * t1190;
  t2269 = my_piecewise3(t2, 0, t2250 * t600 / 0.58320e5 + t2253 / 0.43740e5 - 0.2e1 / 0.10935e5 * t1183 * t1191 - t2260 - 0.4e1 / 0.32805e5 * t2262 + 0.19e2 / 0.32805e5 * t597 * t598 * t54 * t344);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[0] = t8 * t2269 + 0.2e1 * t1195;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[4] = 0.0e0;

  t2272 = t7 * t365;
  t2275 = t1197 * t1200;
  t2279 = t604 * t2257 * t605 / 0.262440e6;
  t2281 = my_piecewise3(t82, 0, t2272 * t606 / 0.58320e5 + t2275 / 0.43740e5 - t2279);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[5] = t8 * t2281 + 0.2e1 * t1204;

  t2283 = t7 * t390;
  t2286 = t1206 * t1187;
  t2293 = my_piecewise3(t2, 0, t2283 * t600 / 0.58320e5 + t2286 / 0.87480e5 - t1206 * t1191 / 0.10935e5 + t2253 / 0.87480e5 - t2260 - 0.2e1 / 0.32805e5 * t2262);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[6] = t8 * t2293 + t1195 + t1210;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[10] = 0.0e0;

  t2295 = t7 * t414;
  t2298 = t1212 * t1200;
  t2304 = t604 * t1186 * t1215;
  t2307 = my_piecewise3(t82, 0, t2295 * t606 / 0.58320e5 + t2298 / 0.87480e5 + t2275 / 0.87480e5 - t2279 - t1197 * t1216 / 0.10935e5 - 0.2e1 / 0.32805e5 * t2304);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[11] = t8 * t2307 + t1204 + t1220;

  t2310 = t7 * t445;
  t2315 = my_piecewise3(t2, 0, t2310 * t600 / 0.58320e5 + t2286 / 0.43740e5 - t2260);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[12] = t8 * t2315 + 0.2e1 * t1210;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[16] = 0.0e0;

  t2318 = t7 * t462;
  t2330 = my_piecewise3(t82, 0, t2318 * t606 / 0.58320e5 + t2298 / 0.43740e5 - 0.2e1 / 0.10935e5 * t1212 * t1216 - t2279 - 0.4e1 / 0.32805e5 * t2304 + 0.19e2 / 0.32805e5 * t604 * t598 * t54 * t489);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigma2[17] = t8 * t2330 + 0.2e1 * t1220;

  t2335 = t1183 * t1224;
  t2340 = t597 * t2257 * t610 / 0.155520e6;
  t2344 = my_piecewise3(t2, 0, -t2250 * t611 / 0.34560e5 - t2335 / 0.25920e5 + 0.13e2 / 0.51840e5 * t1184 + t2340 + 0.13e2 / 0.77760e5 * t1188 - 0.13e2 / 0.19440e5 * t1192);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[0] = t8 * t2344 + 0.2e1 * t1229;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[4] = 0.0e0;

  t2349 = t1197 * t1233;
  t2353 = t604 * t2257 * t615 / 0.155520e6;
  t2355 = my_piecewise3(t82, 0, -t2272 * t616 / 0.34560e5 - t2349 / 0.25920e5 + t2353);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[5] = t8 * t2355 + 0.2e1 * t1237;

  t2359 = t1206 * t1224;
  t2365 = my_piecewise3(t2, 0, -t2283 * t611 / 0.34560e5 - t2359 / 0.51840e5 + 0.13e2 / 0.103680e6 * t1207 - t2335 / 0.51840e5 + t2340 + 0.13e2 / 0.155520e6 * t1188);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[6] = t8 * t2365 + t1229 + t1242;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[10] = 0.0e0;

  t2369 = t1212 * t1233;
  t2375 = my_piecewise3(t82, 0, -t2295 * t616 / 0.34560e5 - t2369 / 0.51840e5 - t2349 / 0.51840e5 + t2353 + 0.13e2 / 0.103680e6 * t1198 + 0.13e2 / 0.155520e6 * t1201);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[11] = t8 * t2375 + t1237 + t1248;

  t2382 = my_piecewise3(t2, 0, -t2310 * t611 / 0.34560e5 - t2359 / 0.25920e5 + t2340);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[12] = t8 * t2382 + 0.2e1 * t1242;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[16] = 0.0e0;

  t2392 = my_piecewise3(t82, 0, -t2318 * t616 / 0.34560e5 - t2369 / 0.25920e5 + 0.13e2 / 0.51840e5 * t1213 + t2353 + 0.13e2 / 0.77760e5 * t1201 - 0.13e2 / 0.19440e5 * t1217);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmalapl[17] = t8 * t2392 + 0.2e1 * t1248;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2sigmatau[17] = 0.0e0;

  t2397 = t1183 * t1252;
  t2402 = t597 * t2257 * t620 / 0.87480e5;
  t2406 = my_piecewise3(t2, 0, t2250 * t621 / 0.19440e5 + t2397 / 0.14580e5 - t1222 / 0.2916e4 - t2402 - t1225 / 0.4374e4 + 0.13e2 / 0.17496e5 * t601);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapl2[0] = t8 * t2406 + 0.2e1 * t1257;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapl2[1] = 0.0e0;

  t2411 = t1197 * t1261;
  t2415 = t604 * t2257 * t625 / 0.87480e5;
  t2417 = my_piecewise3(t82, 0, t2272 * t626 / 0.19440e5 + t2411 / 0.14580e5 - t2415);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapl2[2] = t8 * t2417 + 0.2e1 * t1265;

  t2421 = t1206 * t1252;
  t2427 = my_piecewise3(t2, 0, t2283 * t621 / 0.19440e5 + t2421 / 0.29160e5 - t1239 / 0.5832e4 + t2397 / 0.29160e5 - t2402 - t1225 / 0.8748e4);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapl2[3] = t8 * t2427 + t1257 + t1270;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapl2[4] = 0.0e0;

  t2431 = t1212 * t1261;
  t2437 = my_piecewise3(t82, 0, t2295 * t626 / 0.19440e5 + t2431 / 0.29160e5 + t2411 / 0.29160e5 - t2415 - t1231 / 0.5832e4 - t1234 / 0.8748e4);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapl2[5] = t8 * t2437 + t1265 + t1276;

  t2444 = my_piecewise3(t2, 0, t2310 * t621 / 0.19440e5 + t2421 / 0.14580e5 - t2402);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapl2[6] = t8 * t2444 + 0.2e1 * t1270;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapl2[7] = 0.0e0;

  t2454 = my_piecewise3(t82, 0, t2318 * t626 / 0.19440e5 + t2431 / 0.14580e5 - t1244 / 0.2916e4 - t2415 - t1234 / 0.4374e4 + 0.13e2 / 0.17496e5 * t607);
  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapl2[8] = t8 * t2454 + 0.2e1 * t1276;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2lapltau[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2tau2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2tau2[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2tau2[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2tau2[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2tau2[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2tau2[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2tau2[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2tau2[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rho2tau2[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[18] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma3[19] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[18] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[19] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[20] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[21] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[22] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2lapl[23] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[18] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[19] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[20] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[21] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[22] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigma2tau[23] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapl2[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[18] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[19] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[20] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[21] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[22] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmalapltau[23] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhosigmatau2[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl3[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl3[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl3[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl3[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl3[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl3[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl3[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl3[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapl2tau[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rholapltau2[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhotau3[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhotau3[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhotau3[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhotau3[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhotau3[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhotau3[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhotau3[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4rhotau3[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma4[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[18] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3lapl[19] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[18] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma3tau[19] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapl2[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[18] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[19] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[20] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[21] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[22] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2lapltau[23] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigma2tau2[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl3[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapl2tau[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[12] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[13] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[14] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[15] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[16] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmalapltau2[17] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[9] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[10] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4sigmatau3[11] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl4[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl4[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl4[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl4[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl4[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl3tau[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl3tau[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl3tau[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl3tau[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl3tau[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl3tau[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl3tau[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl3tau[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl2tau2[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl2tau2[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl2tau2[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl2tau2[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl2tau2[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl2tau2[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl2tau2[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl2tau2[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapl2tau2[8] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapltau3[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapltau3[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapltau3[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapltau3[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapltau3[4] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapltau3[5] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapltau3[6] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_NEEDS_LAPLACIAN) && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4lapltau3[7] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4tau4[0] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4tau4[1] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4tau4[2] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4tau4[3] = 0.0e0;

  if(v4rho4 != NULL && (p->info->flags & XC_FLAGS_HAVE_LXC))
    v4tau4[4] = 0.0e0;

#ifndef XC_DONT_COMPILE_MXC

  if(order < 5) return;


#endif

#endif

#endif

#endif

#endif


}

